from AccessControl import ClassSecurityInfo
from Products.TabbedSubpages.schemata import TabbedSubpages
from Products.ATContentTypes.content.document import ATDocument
from Products.CMFCore.permissions import View

from Products.TabbedSubpages.config import TYPE_PARAMS

from time import sleep

try:
    from Products.CMFDynamicViewFTI.interfaces import ISelectableBrowserDefault
    HAS_ISBD = True
except ImportError:
    HAS_ISBD = False

class TabbedSubpages(ATDocument):
    """
    Represents a page aggregating the content of referenced "sub-pages".
    Each sub-page gets a tab so that only one sub-page is shown at a time.
    """
    
    security = ClassSecurityInfo()
    
    portal_type = meta_type = TYPE_PARAMS['TabbedSubpages']['portal_type']
    archetype_name = TYPE_PARAMS['TabbedSubpages']['archetype_name']
    immediate_view = default_view = TYPE_PARAMS['TabbedSubpages']['default_view']
    
    actions = ({ 'id': 'view'
             , 'name': 'View'
             , 'action': 'string:${object_url}/' + default_view
             , 'permissions': (View,)
             },
            )
    
    schema = TabbedSubpages.schema
    
    security.declareProtected(View, 'getTargetObjectLayout')
    def getTargetObjectLayout(self, target):
        """
        Returns target object 'view' action page template
        """
        
        if HAS_ISBD and ISelectableBrowserDefault.isImplementedBy(target):
            return target.getLayout()
        else:
            view = target.getTypeInfo().getActionById('view') or 'base_view'
            
            # If view action is view, try to guess correct template
            if view == 'view':
                view = target.portal_type.lower() + '_view'
                
            return view
            
    def SearchableText(self):
        """Append references' searchable fields."""
        
        data = [ATDocument.SearchableText(self),]
        
        subpages = self.getSubpages()
        for subpage in subpages:
            data.append(subpage.SearchableText())
            
        data = ' '.join(data)
        
        return data
    
try:
  from Products.LinguaPlone.public import registerType
except ImportError:
  from Products.Archetypes.public import registerType
  
registerType(TabbedSubpages)
